/* testing TestRGF.java, Rony G. Flatscher, 2001-04-25

   purpose: this Rexx program demonstrates the usage of the Java class "TestRGF"
            and demonstrates the usage of the BSF-interface, concentrating on
            accessing arrays

   invoke:  enter the following command to inoke the Rexx program "testArrays-oo.rex":

                  "java com.ibm.bsf.Main -lang rexx -in testArrays-oo.rex"
            or
                  "java com.ibm.bsf.Main -in testArrays-oo.rex"

            if extension "rex" is defined in the text file "\com\ibm\bsf\Languages.properties",
            which allows for determining the needed engine by looking at the file extension
*/

if rxFuncQuery("BSF") then  /* no bsf4rexx support available yet, hence load Java */
do
   call rxFuncAdd "BsfLoadFuncs", "BSF4Rexx", "BsfLoadFuncs"
   call BsfLoadFuncs    /* load all BSF-functions                    */
   call BsfLoadJava     /* load the JVM and set up BSF4Rexx-support  */
end

if      BsfInvokedBy()=1 then say "This Rexx program was invoked by Java!"
else if BsfInvokedBy()=2 then say "This Rexx program was invoked by Rexx, JVM loaded by Rexx!"
else                          say "No JVM present, we got troubles ..."

.bsf~import("TestRGF", "TestRGF")
tr1 = .testRGF~new

say "tr1:" tr1 "class:" tr1~class

f3 = tr1~bsf.getFieldValue( "statField3" )
f4 = tr1~bsf.getFieldValue( "statField4" )
f5 = tr1~bsf.getFieldValue( "statField5" )
f6 = tr1~bsf.getFieldValue( "statField6" )
f7 = tr1~bsf.getFieldValue( "statField7" )

say
call dump_array f3
say

        -- index 1-based (Object Rexx standard for arrays, gets adjusted for Java automatically)
f3~put("string", "un"    , 1             )
f4~put("string", "deux"  , 1, 2          )
f5~put("string", "trois" , 1, 2, 3       )
f6~put("string", "quatre", 1, 2, 3, 4    )

        -- syntax variant, indexing with square brackets
        -- please note: in this case the first word of the "newValue"-string
        --              *must* be the typeIndicator followed by a blank, followed
        --              by the value to set the array element to
f6[1, 2, 3, 1] = "string quatre2"

f7~put("string", "cinq"  , 1, 2, 3, 4, 5 )

say left("", 79, "-")
say
say "Now retrieving the stored values from the arrays:"
say
say "statField3[1]            : [" || f3~at(1            ) || "]"
say "statField4[1][2]         : [" || f4~at(1, 2         ) || "]"
say "statField5[1][2][3]      : [" || f5~at(1, 2, 3      ) || "]"
say "statField6[1][2][3][4]   : [" || f6~at(1, 2, 3, 4   ) || "]"

say "statField6[1][2][3][1]   : [" || f6[1, 2, 3, 1]       || "]"       -- syntax variant!

say "statField7[1][2][3][4][5]: [" || f7~at(1, 2, 3, 4, 5) || "]"

say left("", 79, "-")
say
say "statField7[1][2][3][4][5]: [" || f7[1, 2, 3, 4, 5]    || "]"       -- syntax variant!

say
say "...null string to indicate a Java-Null is: [".bsf~null_string"]"
say
say "statField7[1][1][1][1][1]: [" || f7[1, 1, 1, 1, 1]    || "]"       -- syntax variant!, .nil
say "...setting the above array element to: 'hey!'..."
f7~put("string", "hey!", 1,1,1,1,1)
say "statField7[1][1][1][1][1]: [" || f7[1, 1, 1, 1, 1]    || "]"       -- syntax variant!, .nil
say "... setting array element to .nil again ..."
f7~put("string", .nil, 1,1,1,1,1)
say "statField7[1][1][1][1][1]: [" || f7[1, 1, 1, 1, 1]    || "]"       -- syntax variant!, .nil

say
say "...now changing null string:"

.bsf~setRexxNullString("NULL_nil_NOTHING_OH")   -- change
say
say "...null string to indicate a Java-Null is: [".bsf~null_string"]"
say
say "statField7[1][1][1][1][1]: [" || f7[1, 1, 1, 1, 1]    || "]"       -- syntax variant!, .nil
say "...setting the above array element to: 'hey!'..."
f7~put("string", "hey!", 1,1,1,1,1)
say "statField7[1][1][1][1][1]: [" || f7[1, 1, 1, 1, 1]    || "]"       -- syntax variant!, .nil
say "... setting array element to .nil again ..."
f7~put("string", .nil, 1,1,1,1,1)
say "statField7[1][1][1][1][1]: [" || f7[1, 1, 1, 1, 1]    || "]"       -- syntax variant!, .nil


say left("", 79, "-")

say
say "trying to get the field length of the array:"
say
say "length:" f7~dimension(1)  "length (size) of first dimension"
say "length:" f7~dimension(2)  "length (size) of second dimension"
say "length:" f7~dimension(3)  "length (size) of third dimension"
say "length:" f7~dimension(4)  "length (size) of fourth dimension"
say "length:" f7~dimension(5)  "length (size) of fifth dimension"
say
say "items in array f7:" f7~items
say
call dump_array f3
exit

dump_array: procedure
   use arg javaArray

   say left("", 79, "-")
   say
   say "looping over <"javaArray">:"
   say
   do i=1 to javaArray~items    -- note: Object Rexx arrays are "1"-based (will get adjusted by bsf.cls)
      say "Object Rexx-index:" i "value: [" || javaArray[i] || "]"
   end
   return

::requires "BSF.cls"    -- get access to the BSF-supporting Object Rexx classes

